@@ -45,16 +45,27 @@ builtin_legends = {
     },
     # https://samapriya.github.io/awesome-gee-community-datasets/projects/esrilc2020/
     "ESRI_LandCover": {
-        "Water": "1A5BAB",
-        "Trees": "358221",
-        "Grass": "A7D282",
-        "Flooded Vegetation": "87D19E",
-        "Crops": "FFDB5C",
-        "Scrub/Shrub": "EECFA8",
-        "Built Area": "ED022A",
-        "Bare Ground": "EDE9E4",
-        "Snow/Ice": "F2FAFF",
-        "Clouds": "C8C8C8",
+        "1 Water": "1A5BAB",
+        "2 Trees": "358221",
+        "3 Grass": "A7D282",
+        "4 Flooded Vegetation": "87D19E",
+        "5 Crops": "FFDB5C",
+        "6 Shrub & Scrub": "EECFA8",
+        "7 Built Area": "ED022A",
+        "8 Bare Ground": "EDE9E4",
+        "9 Snow/Ice": "F2FAFF",
+        "10 Clouds": "C8C8C8",
+    },
+    "Dynamic_World": {
+        "0 Water": "419BDF",
+        "1 Trees": "397D49",
+        "2 Grass": "88B053",
+        "3 Flooded vegetation": "7A87C6",
+        "4 Crops": "E49635",
+        "5 Shrub & Scrub": "DFC35A",
+        "6 Built-up area": "C4281B",
+        "7 Bare ground": "A59B8F",
+        "8 Snow & Ice": "B39FE1",
     },
     # National Wetlands Inventory Legend: https://www.fws.gov/wetlands/data/Mapper-Wetlands-Legend.html
     "NWI": {
